@@ -25,7 +25,7 @@ use tokio::sync::Mutex;
 
 use async_recursion::async_recursion;
 
-use chrono::offset::Local;
+use chrono::{offset::Local, SecondsFormat};
 
 use super::socket::*;
 use super::portable;
@@ -422,7 +422,8 @@ impl SyslogInternal
             };
 
         // get timedate
-        let timedate = Local::now().to_rfc3339();
+        let timedate = 
+            Local::now().to_rfc3339_opts(SecondsFormat::Secs, false);
 
         // get appname
         if self.logtag.is_none() == true
@@ -472,7 +473,7 @@ impl SyslogInternal
                 // structured data
                 " ".as_bytes(), NILVALUE.as_bytes(), 
                 // msg
-                " ".as_bytes(), b"\xEF\xBB\xBF", msg_final.as_bytes()
+                " ".as_bytes(), /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
             ].concat();
         
         // output to stderr if required
